Method: JSS::Computer#software
- Defined in:
- lib/jss-api/api_object/computer.rb
#software ⇒ Hash (readonly)
A Hash of software data
The Hash has these keys:
- :running_services => An Array of services running on the computer (if gathered) TODO - is each item a hash?
- :installed_by_casper => An Array of Package names unstalled on this computer by Casper
- :fonts => An Array of fonts on this computer (if gathered) TODO - is each item a hash?
- :installed_by_installer_swu => An Array of pkg IDs for pkgs installed by SoftwareUpdate or the Apple Installer
- :applications => An Array of Hashes, one per Application on the computer, with these keys:
- :path => String, the path to the app
- :name => String, the name of the app, including the .app suffix
- :version => String, the version of the app at that path.
- :cached_by_casper => An Array of Casper Package names cached on the machine, awaiting installation
- :available_software_updates => An Array of available SoftwareUpdate (if gathered) TODO - is each item a hash?
- :plugins => An Array of plugins installed on the machine (if gathered) TODO - is each item a hash?
- :available_updates => A Hash - Deprecated?
- :licensed_software => An Array, the names of Licenced Software (as defined in Casper) on this machine
- :unix_executables => DEPRECATED
529 530 531 |
# File 'lib/jss-api/api_object/computer.rb', line 529 def software @software end |