Method: JSS::ComputerExtensionAttribute#script

Defined in:
lib/jss-api/api_object/extension_attribute/computer_extension_attribute.rb

#scriptString Also known as: code

Returns the script code that will be executed when the @input_type is “script”,.

Returns:

  • (String)

    the script code that will be executed when the @input_type is “script”,



117
118
119
# File 'lib/jss-api/api_object/extension_attribute/computer_extension_attribute.rb', line 117

def script
  @script
end